% The script plot for wild type and KO at 35 DIV samples of activity, 
% corresponding spike-time histogram, the average burst profile, 
% the power spectral density of burst decay, the bursts profile
% the input file is spike_time.mat

clear all
close all
fig = figure('PaperUnits', 'centimeters');
set(fig,'visible','on','Color','w', 'render','painters','PaperPosition', [0.05 .05 16 22],'PaperSize', [16 22],'PaperUnits', 'centimeters');
set(0,'DefaultAxesFontSize', 12, 'DefaultTextFontSize', 12, ...
    'DefaultAxesFontName', 'Arial','DefaultTextFontName', 'Arial');

binsize= 0.01; % % Binsize for burst detection in seconds
threshold=10;% Threshold for burst detection (10 spikes during binsize (10 ms))
wait_time=25;% Time (ms) within which crossings of spike rate over the threshold are considered as 1 burst
extention=6/binsize; 
load('spike_time.mat') % load data file

%--------------------WT rasterplot of spontaneous activity across the all electrodes
fileindtemp=strfind(sp_time(:,1),'192_wt_I7298_div35_sp_201412011105'); % WT spikes time
fileind= find(not(cellfun('isempty', fileindtemp)));
SPIKES=sp_time{fileind,2};
[~,tmp]  = sort(SPIKES(:,1));
ax(1)=axes('Position',[.1 .75 0.35 .2]); % axes for samples of activity
hold(ax(1),'on');xlim([95.8 99]);ylim([0 60]);
set(ax(1),'XTick',[95.8:1:99],'XTickLabel',[0 1 2 3]);
set(ax(1),'YTick',[0 60],'YTickLabel',[0 60]);
annotation('textbox', [0.05 ,0.95,0.03,0.04],'String', 'A','fontsize',18,'EdgeColor',[1 1 1]);
plot(ax(1),SPIKES(:,1)/1000,SPIKES(:,2),'k.','MarkerSize',6) % plot WT spikes time
title('WT','fontsize',12, 'fontweight','b')
hold on
ylabel('Electrode no.')
xlabel('Time, sec')
%----------------------spike time histogram to reveal episodic tendency
ax(2)=axes('Position',[.1 .5 0.35 .16]); hold(ax(2),'on');xlim([95.8 99]);ylim([0 160]);
annotation('textbox', [0.05 ,0.67,0.03,0.04],'String', 'B','fontsize',18,'EdgeColor',[1 1 1]);
set(ax(2),'XTick',[95.8:1:99],'XTickLabel',[0 1 2 3 ]);
nbins=1800/binsize;
H=histc(SPIKES(:,1)/1000,[0:binsize:binsize*nbins]); % histogram
xlabel('Time, sec')
ylabel(strcat('N events/',mat2str(1000*binsize),'ms'))
bar(ax(2),[binsize/2:binsize:binsize*nbins+binsize/2],H,...
    'FaceColor',[1, 1, 1],'EdgeColor',[0.6, 0.6, 0.6],'LineWidth',1); 
hold on
burst=find(H>threshold);% Nspikes across all electrodes during binsize exceeds threshold
burst_start=[1;find(diff(burst)>wait_time)+1];
burst_end=[find(diff(burst)>wait_time);length(burst)];
burst_edges=[burst(burst_start)*binsize-binsize/2 burst(burst_end)*binsize-binsize/2];% left 
%-------------------- left and right edges of burst in seconds
for j=1:length(burst_edges)
B_temp=H((burst(burst_start(j))-5):(burst(burst_end(j))+10));
        %5*binsize 125ms before start and 250 ms after end of burst
B_temp(extention,1)=0;
B_profile(:,j)=B_temp;     
%Align bursts profiles with respect to cross-correlation
DD(j,:) = finddelay(B_profile(:,1),B_profile(:,j));
Align_burst_C(:,j)=circshift(B_profile(:,j),-DD);
end
annotation('textbox', [0.05 ,0.42,0.03,0.04],'String', 'C','fontsize',18,'EdgeColor',[1 1 1]);
ax(3)=axes('Position',[.1 .27 0.35 .15]); hold(ax(3),'on');xlim([0 2.5]);ylim([0 120]);
set(ax(3),'XTick',[0 2.5],'XTickLabel',[ ]);
S(:,2)=sum(Align_burst_C,2)/size(Align_burst_C,2); %Average WT burst profile
plot(ax(3),[0:binsize:binsize*(extention-1)],S(1:extention,2),'color',[0.6 0.6 0.6],'linewidth',1.5)
%ylabel('spikes/10 ms','fontweight','b')
ylabel('Average burst profile')

ax(4)=axes('Position',[.3 .35 0.15 .07]); hold(ax(4),'on');xlim([5 50]);
srate=1/binsize;
a=50;    b=150; % boundary of burst decay for fft
DATA=S(a:b,2);  
NFFT = 2^nextpow2(length(DATA)); % Next power of 2 from length of DATA
    Furie=fft(DATA(:,1),NFFT); %  FFT
    Amplituda=2*abs(Furie)/NFFT; % 
    PSD=2*(abs(Furie)).^2/NFFT; %Power Spectral Density
    Freq=0:srate/NFFT:srate/2-1/NFFT;% 
    plot(ax(3),a*binsize,[0:1:20],'k- ')
    plot(ax(3),b*binsize,[0:1:20],'k- ')
    plot(ax(4),Freq,PSD(1:NFFT/2),'color', [0.6 0.6 0.6],'linewidth',2);  % Plot single-sided spectrum.
    hold on
    xlabel('Frequency, Hz')
    ylabel('PSD, a.u.')

ax(5)=axes('Position',[.1 .067 0.35 .19]); hold(ax(5),'on');
ylim([1 size(Align_burst_C,2)]); xlim([1 2.5/binsize])
set(ax(5),'XTick',[0:50:250],'XTickLabel',[0 0.5 1 1.5 2 2.5]);
imagesc(Align_burst_C') % presentation by pseudo-colours of WT individual burst profile
ylabel('# burst')
xlabel('Time, sec')
clear Align_burst_C  I SPIKES fileindtemp fileind

%--------------------KO-rasterplot of spontaneous activity across the all electrodes
fileindtemp=strfind(sp_time(:,1),'199_ko_I7494_div35_sp_201412231728'); %KO spikes time
fileind= find(not(cellfun('isempty', fileindtemp)));
SPIKES=sp_time{fileind,2};
[~,tmp]  = sort(SPIKES(:,1));
%---------------------- rasterplot of spontaneous activity across the all electrodes
ax(11)=axes('Position',[.6 .75 0.35 .2]); hold(ax(11),'on'); % axes for samples of activity
xlim([729.5 732.7]);ylim([0 60]);
set(ax(11),'XTick',[729.5:1:732.7],'XTickLabel',[0 1 2 3]);
set(ax(11),'YTick',[0 60],'YTickLabel',[0 60]);
plot(ax(11),SPIKES(:,1)/1000,SPIKES(:,2),'k.','MarkerSize',6) % plot KO spikes time
title('KO','fontsize',12, 'fontweight','b')
hold on
ylabel('Electrode no.')
xlabel('Time, sec')
%---------------------- time histogram to reveal episodic tendency
ax(12)=axes('Position',[.6 .5 0.35 .16]); hold(ax(12),'on');xlim([729.5 732.7]);;ylim([0 160]);
set(ax(12),'XTick',[729.5:1:732.7],'XTickLabel',[0 1 2 3]);
nbins=1800/binsize;
H=histc(SPIKES(:,1)/1000,[0:binsize:binsize*nbins]); % histogram
xlabel('Time, sec')
ylabel(strcat('N events/',mat2str(1000*binsize),'ms'))
bar(ax(12),[binsize/2:binsize:binsize*nbins+binsize/2],H,...
    'FaceColor',[0, 0,0],'EdgeColor',[0, 0, 0],'LineWidth',1); %
hold on
burst=find(H>threshold);% Nspikes across all electrodes during binsize exceeds threshold
burst_start=[1;find(diff(burst)>wait_time)+1];
burst_end=[find(diff(burst)>wait_time);length(burst)];
burst_edges=[burst(burst_start)*binsize-binsize/2 burst(burst_end)*binsize-binsize/2];% left 

%-------------------- left and right edges of burst in seconds
for j=1:length(burst_edges)
B_temp=H((burst(burst_start(j))-5):(burst(burst_end(j))+10));
        %5*binsize 125ms before start and 250 ms after end of burst
B_temp(extention,1)=0;
B_profile(:,j)=B_temp;     
%-----Align bursts profiles with respect to the cross-correlation value             
DD(j,:) = finddelay(B_profile(:,1),B_profile(:,j));
Align_burst_C(:,j)=circshift(B_profile(:,j),-DD);
end
%-------------alignment to ....
ax(13)=axes('Position',[.6 .27 0.35 .15]); hold(ax(13),'on');xlim([0 2.5]);ylim([0 120]);
set(ax(13),'XTick',[0 2.5],'XTickLabel',[ ]);
S(:,2)=sum(Align_burst_C,2)/size(Align_burst_C,2); %Average KO burst profile
plot(ax(13),[0:binsize:binsize*(extention-1)],S(1:extention,2),'color',[0 0 0],'linewidth',1.5)
%ylabel('spikes/10 ms','fontweight','b')
ylabel('Average burst profile')

ax(14)=axes('Position',[.8 .35 0.15 .07]); hold(ax(14),'on');xlim([5 50]);
srate=1/binsize;
a=50; b=150;    % boundary of burst decay for fft
DATA=S(a:b,2);
NFFT = 2^nextpow2(length(DATA)); % Next power of 2 from length of DATA
    Furie=fft(DATA(:,1),NFFT); % FFT
    PSD=2*(abs(Furie)).^2/NFFT; %Power Spectral Density
    Freq=0:srate/NFFT:srate/2-1/NFFT;% 
    plot(ax(13),a*binsize,[0:1:20],'k- ')
    plot(ax(13),b*binsize,[0:1:20],'k- ')
    plot(ax(14),Freq,PSD(1:NFFT/2),'color', [0 0 0],'linewidth',2);  % Plot single-sided spectrum.
    hold on
    xlabel('Frequency, Hz')
    ylabel('PSD, a.u.')
ax(15)=axes('Position',[.6 .067 0.35 .19]); hold(ax(15),'on');
ylim([1 size(Align_burst_C,2)]); xlim([1 2.5/binsize])
set(ax(15),'XTick',[0:50:250],'XTickLabel',[0 0.5 1 1.5 2 2.5]);
imagesc(Align_burst_C') % presentation by pseudo-colours of WT individual burst profile
ylabel('# burst')
xlabel('Time, sec')
%-------------------------------
% print(gcf,'-dtiff','BurstProfile','-r300')