% The first part of the script calculates and plots the mean firing rate and 
% the mean burst rate over all days in vitro for WT and KO recordings. 
% The second part of the script uses anova and tests the two-factor
% interactions: conditions(wt/ko) and days in vitro.
% the input file is data.mat

clear all
fig = figure('PaperUnits', 'centimeters');
set(fig,'visible','on','Color','w', 'PaperPosition', [0.05 .05 12 7],...
    'PaperSize', [13 10],'PaperUnits', 'centimeters','PaperOrientation','Portrait');
set(0, ...
    'DefaultAxesFontSize', 12,'DefaultTextFontSize', 12, ...
    'DefaultAxesFontName', 'Arial','DefaultTextFontName', 'Arial');
load('data.mat') % load data file
Result=data;
D=['div07';'div09'; 'div14'; 'div21'; 'div28'; 'div35']; % days in vitro for represantation
ax(1) = axes('Position',[.15 .1 0.35 .7]); % axes for Firing Rate;
hold(ax(1),'on'); xlim([0 7]);ylim([0 300]);
ylabel('Firing rate,[1/s]')
set(ax(1),'XTick',[1:1:6],'XTickLabel',['07';'09'; '14'; '21'; '28'; '35'],'YTick',[0:100:300]);
ax(2) = axes('Position',[.6 .1 0.35 .7]); % axes for Burst Rate;
hold(ax(2),'on'); xlim([0 7]);ylim([0 15]);
set(ax(2),'XTick',[1:1:6],'XTickLabel',['07';'09'; '14'; '21'; '28'; '35']);
ylabel('Burst rate,[1/min]')
for k=1:6 % loop for days in vitro 
DIV=D(k,:); 
WT=[]; % wild type data
KO=[]; % KO data
    for j=1:length(Result)
             if (strcmp(cellstr(Result(j,2)),DIV) & strcmp(cellstr(Result(j,1)),'wt'));
                WT=[WT; Result(j,:)];
             elseif (strcmp(cellstr(Result(j,2)),DIV) & strcmp(cellstr(Result(j,1)),'ko'))
                KO=[KO; Result(j,:)];
            end
    end
%---------Mean of number of spikes
NS_wt=nanmean(cell2mat(WT(:,3))/1800); %mean spike rate for WT
NS_ko=nanmean(cell2mat(KO(:,3))/1800); %mean spike rate for KO
sem_WT=std(cell2mat(WT(:,3))/1800)/sqrt(length(cell2mat(WT(:,3)))); %error of the mean for WT
errorbar(ax(1),k-0.2,NS_wt,sem_WT,'color','k','linewidth',1)
bar(ax(1),k-0.2,NS_wt,'w','BarWidth',.4);
hold on
sem_KO=std(cell2mat(KO(:,3))/1800)/sqrt(length(cell2mat(KO(:,3)))); %error of the mean for KO
errorbar(ax(1),k+0.2,NS_ko,sem_KO,'color','k','linewidth',1)
bar(ax(1),k+0.2,NS_ko,'k','BarWidth',.4);
%---------Mean of number of Burst
NB_wt=nanmean(cell2mat(WT(:,4))/30); %mean burst rate for WT
NB_ko=nanmean(cell2mat(KO(:,4))/30); %mean burst rate for KO
sem_WT=std(cell2mat(WT(:,4))/30)/sqrt(length(cell2mat(WT(:,4)))); %error of the mean for WT
errorbar(ax(2),k-0.2,mean(cell2mat(WT(:,4))/30),sem_WT,'color','k','linewidth',1)
bar(ax(2),k-0.2,NB_wt,'w','BarWidth',.4);
hold on
sem_KO=std(cell2mat(KO(:,4))/30)/sqrt(length(cell2mat(KO(:,4)))); %error of the mean for KO
errorbar(ax(2),k+0.2,mean(cell2mat(KO(:,4))/30),sem_KO,'color','k','linewidth',1)
bar(ax(2),k+0.2,NB_ko,'k','BarWidth',.4);
end
axes(ax(1))
sigstar({[3.8,4.2],[4.8,5.2],[5.8,6.2]},[0.01,0.01,0.01]);
plot([2],[260],'w.')
sigstar({[1.5,4.5]},[0.01]);
plot([1-0.3 2+0.3],[272 272],'k','linewidth', 1)
plot([3-0.3 6+0.3],[272 272],'k','linewidth', 1)
annotation('textbox', [0.04,0.9,0.03,0.04],'String', 'A','fontsize',18,'EdgeColor',[1 1 1]);
axes(ax(2))
sigstar({[3.8,4.2],[5.8,6.2]},[0.05,0.05]);
plot([2],[12.8],'w.')
sigstar({[1.5,3.5]},[0.01]);
plot([1-0.3 2+0.3],[13.4 13.4],'k', 'linewidth', 1)
plot([3-0.3 4+0.3],[13.4 13.4],'k','linewidth', 1)
annotation('textbox', [0.5,0.9,0.03,0.04],'String', 'B','fontsize',18,'EdgeColor',[1 1 1]);
% print(fig,'-dtiff','MeanActivity','-r300')
%-----------------------------------------------------------------------------------------------
%%
T=[];
for k=1:6 % loop for days in vitro
    DIV=D(k,:); 
    Table=[];
    for j=1:length(data)
             if (strcmp(cellstr(data(j,2)),DIV)); 
                Table=[Table; data(j,:)];
             end
     end
T=[T;Table]; 
end
%------------ANOVA---------------------------------------------------------
% --------Number of spikes
NS=T(find(~cellfun(@isempty,T(:,3))),1:3);
groupNS={NS(:,1);NS(:,2)};
[~,~,stats] =anovan(cell2mat(NS(:,3)),groupNS,'model','interaction','varnames',{'type','div'});
resultsNS = multcompare(stats,'Alpha',0.01,'CType','lsd','Dimension',[1 2],'Display','off');%Fisher's least significant difference procedure post-hoc test
% --------Number of BURSTs
NB=T(find(~cellfun(@isempty,T(:,4))),[1,2,4]);
groupNB={NB(:,1);NB(:,2)};
[~,~,stats] =anovan(cell2mat(NB(:,3)),groupNB,'model','interaction','varnames',{'type','div'});
resultsNB = multcompare(stats,'Alpha',0.05,'CType','lsd','Dimension',[1 2],'Display','off'); %Fisher's least significant difference procedure post-hoc test

